@@ -59,6 +59,6 @@ def Track(boxes, classes, confidence, frame):
         bbox = track.to_tlbr()
         # cv2.rectangle(frame, (int(bbox[i][0]), int(bbox[i][1])), (int(bbox[i][2]), int(bbox[i][3])), (255, 255, 255), 2)
         cv2.putText(frame, "ID: " + str(track.track_id), (int(bbox[0]), int(bbox[1])), 0,
-                    1.5e-3 * frame.shape[0], (0, 255, 0), 1)
+                    0.5, (0, 255, 0), 2)
 
     return frame
\ No newline at end of file
